/**
* @license
* SPDX-License-Identifier: AGPL-3.0-only
* Copyright (C) 2010-2021, Josef Hahn
*/

import {subsite} from '../backend/common.js';


export async function animateNode(node, animationname, animationduration) {
    animationduration = animationduration || getComputedStyle(document.body).getPropertyValue("--sl-transition-slow");
    if (node.style.animationName == animationname) {
        node.style.animationName = "";
        return new Promise((resolve, reject) => {
            setTimeout(() => {
                animateNode(node, animationname, animationduration).then(resolve, reject);
            });
        });
    }
    else
        return new Promise((resolve, reject) => {
            var curreq = node._curreq = new Object();
            function _animationended() {
                node.removeEventListener("animationend", _animationended);
                if (curreq == node._curreq) {
                    node.style.animationName = '';
                    resolve(true);
                }
                else
                    resolve(false);
            }
            node.addEventListener("animationend", _animationended);
            node.style.animationDuration = animationduration;
            node.style.animationFillMode = "forwards";
            node.style.animationName = animationname;
        });
}

/**
* Animates the expansion of a node.
*/
export async function animateExpandNode(node) {
    node.style.maxHeight = 0;
    node.style.opacity = 0;
    node.style.display = "";
    if (await animateNode(node, "ginger-nodeexpand")) {
        node.style.maxHeight = "";
        node.style.opacity = "";
    }
}

/**
* Animates the collapsing of a node.
*/
export async function animateCollapseNode(node) {
    node.style.maxHeight = `${node.getBoundingClientRect().height}px`;
    if (await animateNode(node, "ginger-nodecollapse"))
        node.style.display = "none";
}

/**
* Returns a html snippet that include the base css styling inside shadow dom.
*/
export function baseStylesRef() {
    return `<link rel="stylesheet" href="${subsite}static/pageresources/base.css" type="text/css"/>`;
}

/**
* Shows a dialog.
*/
export function showShoelaceDialog(dialogName) {
    var dialog = document.createElement(dialogName);
    document.body.appendChild(dialog);
    dialog._dialog.addEventListener("sl-after-hide", (event) => {
        if (event.target == dialog._dialog)
            document.body.removeChild(dialog);
    });
    dialog._dialog.show();
    return dialog;
}
